==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/mail/XMailService.hpp <==
#ifndef _COM_SUN_STAR_MAIL_XMAILSERVICE_HPP_
#define _COM_SUN_STAR_MAIL_XMAILSERVICE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_MAIL_XMAILSERVICE_HDL_
#include "com/sun/star/mail/XMailService.hdl"
#endif

#ifndef _COM_SUN_STAR_AUTH_AUTHENTICATIONFAILEDEXCEPTION_HPP_
#include "com/sun/star/auth/AuthenticationFailedException.hpp"
#endif
#ifndef _COM_SUN_STAR_MAIL_XAUTHENTICATOR_HPP_
#include "com/sun/star/mail/XAuthenticator.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_NOTCONNECTEDEXCEPTION_HPP_
#include "com/sun/star/io/NotConnectedException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XCURRENTCONTEXT_HPP_
#include "com/sun/star/uno/XCurrentContext.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_MAIL_XCONNECTIONLISTENER_HPP_
#include "com/sun/star/mail/XConnectionListener.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_UNKNOWNHOSTEXCEPTION_HPP_
#include "com/sun/star/io/UnknownHostException.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_NOROUTETOHOSTEXCEPTION_HPP_
#include "com/sun/star/io/NoRouteToHostException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_CONNECTEXCEPTION_HPP_
#include "com/sun/star/io/ConnectException.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_ALREADYCONNECTEDEXCEPTION_HPP_
#include "com/sun/star/io/AlreadyConnectedException.hpp"
#endif
#ifndef _COM_SUN_STAR_MAIL_MAILEXCEPTION_HPP_
#include "com/sun/star/mail/MailException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::mail::XMailService >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.mail.XMailService" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::mail::XMailService::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::mail::XMailService > * >(0));
}

#endif // _COM_SUN_STAR_MAIL_XMAILSERVICE_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/mail/XMailService.hpp <==
#ifndef _COM_SUN_STAR_MAIL_XMAILSERVICE_HPP_
#define _COM_SUN_STAR_MAIL_XMAILSERVICE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_MAIL_XMAILSERVICE_HDL_
#include "com/sun/star/mail/XMailService.hdl"
#endif

#ifndef _COM_SUN_STAR_AUTH_AUTHENTICATIONFAILEDEXCEPTION_HPP_
#include "com/sun/star/auth/AuthenticationFailedException.hpp"
#endif
#ifndef _COM_SUN_STAR_MAIL_XAUTHENTICATOR_HPP_
#include "com/sun/star/mail/XAuthenticator.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_NOTCONNECTEDEXCEPTION_HPP_
#include "com/sun/star/io/NotConnectedException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XCURRENTCONTEXT_HPP_
#include "com/sun/star/uno/XCurrentContext.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_MAIL_XCONNECTIONLISTENER_HPP_
#include "com/sun/star/mail/XConnectionListener.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_UNKNOWNHOSTEXCEPTION_HPP_
#include "com/sun/star/io/UnknownHostException.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_NOROUTETOHOSTEXCEPTION_HPP_
#include "com/sun/star/io/NoRouteToHostException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_CONNECTEXCEPTION_HPP_
#include "com/sun/star/io/ConnectException.hpp"
#endif
#ifndef _COM_SUN_STAR_IO_ALREADYCONNECTEDEXCEPTION_HPP_
#include "com/sun/star/io/AlreadyConnectedException.hpp"
#endif
#ifndef _COM_SUN_STAR_MAIL_MAILEXCEPTION_HPP_
#include "com/sun/star/mail/MailException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace mail {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::mail::XMailService const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.mail.XMailService" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::mail::XMailService > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::mail::XMailService > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::mail::XMailService::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::mail::XMailService > * >(0));
}

#endif // _COM_SUN_STAR_MAIL_XMAILSERVICE_HPP_
